import { world } from '@minecraft/server';

// 定义一个对象来存储玩家的坐标点
const savedLocations = {};

// 保存玩家坐标点的函数
function savePlayerLocation(player) {
    // 检查玩家是否具有“灵魂”标签
    if (player.hasTag('灵魂')) {
        // 如果有“灵魂”标签，发送失败消息
        player.sendSystemMessage('§4开启失败，原因：正在处于灵魂出窍状态');
        return; // 退出函数
    }

    const location = {
        x: player.location.x,
        y: player.location.y,
        z: player.location.z,
        dimension: player.dimension.id
    };
    // 使用玩家名作为键来存储坐标
    savedLocations[player.nameTag] = location;

    // 分别执行开启功能的相关命令
    player.runCommand('tickingarea add circle ~ ~ ~ 3 灵魂出窍');
    player.runCommand('summon pa:npcts');
    player.runCommand('title @s[tag=灵魂] actionbar §4开启失败，原因-灵魂出窍模式开启中');
    player.runCommand('gamemode spectator @s');
    player.runCommand('effect @s night_vision 99999 1 true');
    player.runCommand('title @s actionbar 您正在处于 §a灵魂出窍');
    player.runCommand('tag @s add 灵魂');
}

// 传送玩家到保存的坐标点并删除坐标点信息的函数
function teleportAndRemoveSavedLocation(player) {
    const location = savedLocations[player.nameTag];
    if (location) {
        const dimension = world.getDimension(location.dimension);
        player.teleport({
            x: location.x,
            y: location.y,
            z: location.z,
            dimension: dimension // 使用获取到的dimension对象
        });

        // 删除保存的坐标点信息
        delete savedLocations[player.nameTag];

        // 分别执行关闭功能的相关命令
        player.runCommand('kill @e[type=pa:npcts,r=2]');
        player.runCommand('gamemode default @s');
        player.runCommand('title @s[tag=灵魂] actionbar 关闭 §c灵魂出窍');
        player.runCommand('title @s[tag=!灵魂] actionbar §4灵魂出窍未开启');
        player.runCommand('effect @s clear');
        player.runCommand('tickingarea remove ~ ~ ~');
        player.runCommand('tag @s remove 灵魂');
    } else {
    }
}

// 监听玩家聊天事件
world.afterEvents.chatSend.subscribe((event) => {
    const { message } = event;
    const player = event.sender;

    // 玩家输入“开启”时保存当前坐标点
    if (message === "开启") {
        savePlayerLocation(player);
    }

    // 玩家输入“关闭”时传送到保存的坐标点并删除坐标点信息
    if (message === "关闭") {
        teleportAndRemoveSavedLocation(player);
    }

    // 玩家输入“帮助”时显示帮助信息
    if (message === "帮助") {
        player.runCommand('say §e##帮助##');
        player.runCommand('say §a聊天栏输入“§e开启§a”开启灵魂出窍模式');
        player.runCommand('say §a聊天栏输入“§e关闭§a”关闭灵魂出窍模式');
        player.runCommand('say §a再次输入“§e帮助§a”可查看帮助页面');
        player.runCommand('say §a当前版本号§dV 3.0');
        player.runCommand('say §aV4.0更新时间2025年1月27日，更新内容：兼容1.21最新版本');
        player.runCommand('say §a模组作者：§bEnderTrekker');
        player.runCommand('say §a加入我们：§5私信EnderTrekker');
        player.runCommand('say §a获取最新版加入群聊：①群 862144925 ②群 274245829');
        player.runCommand('say §a加入频道获取最新版：【星之海交流频道】：§1§n');
        player.runCommand('say §4模组禁止以任何方式二创再上传');
        player.runCommand('say §4如果遇到任何BUG请立即联系EnderTrekker进行修复');
    }
});